====================
Django Nomad Transaq
====================

Overview
========

Manage your backoffice transactions. Useful for operations, QA, or others.
Still in a concept stage, don't know how and where this will evolve to.
